==> openshift-model-config-6.3.0-sources.jar: io/fabric8/openshift/api/model/config/v1/TLSSecurityProfileFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TLSSecurityProfileFluentImpl<A extends TLSSecurityProfileFluent<A>> extends BaseFluent<A> implements TLSSecurityProfileFluent<A>{
  public TLSSecurityProfileFluentImpl() {
  }
  public TLSSecurityProfileFluentImpl(TLSSecurityProfile instance) {
    this.withCustom(instance.getCustom()); 
    this.withIntermediate(instance.getIntermediate()); 
    this.withModern(instance.getModern()); 
    this.withOld(instance.getOld()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private CustomTLSProfileBuilder custom;
  private IntermediateTLSProfileBuilder intermediate;
  private ModernTLSProfileBuilder modern;
  private OldTLSProfileBuilder old;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCustom instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomTLSProfile getCustom() {
    return this.custom!=null ?this.custom.build():null;
  }
  public CustomTLSProfile buildCustom() {
    return this.custom!=null ?this.custom.build():null;
  }
  public A withCustom(CustomTLSProfile custom) {
    _visitables.get("custom").remove(this.custom);
    if (custom!=null){ this.custom= new CustomTLSProfileBuilder(custom); _visitables.get("custom").add(this.custom);} else { this.custom = null; _visitables.get("custom").remove(this.custom); } return (A) this;
  }
  public Boolean hasCustom() {
    return this.custom != null;
  }
  public TLSSecurityProfileFluent.CustomNested<A> withNewCustom() {
    return new TLSSecurityProfileFluentImpl.CustomNestedImpl();
  }
  public TLSSecurityProfileFluent.CustomNested<A> withNewCustomLike(CustomTLSProfile item) {
    return new TLSSecurityProfileFluentImpl.CustomNestedImpl(item);
  }
  public TLSSecurityProfileFluent.CustomNested<A> editCustom() {
    return withNewCustomLike(getCustom());
  }
  public TLSSecurityProfileFluent.CustomNested<A> editOrNewCustom() {
    return withNewCustomLike(getCustom() != null ? getCustom(): new CustomTLSProfileBuilder().build());
  }
  public TLSSecurityProfileFluent.CustomNested<A> editOrNewCustomLike(CustomTLSProfile item) {
    return withNewCustomLike(getCustom() != null ? getCustom(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildIntermediate instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntermediateTLSProfile getIntermediate() {
    return this.intermediate!=null ?this.intermediate.build():null;
  }
  public IntermediateTLSProfile buildIntermediate() {
    return this.intermediate!=null ?this.intermediate.build():null;
  }
  public A withIntermediate(IntermediateTLSProfile intermediate) {
    _visitables.get("intermediate").remove(this.intermediate);
    if (intermediate!=null){ this.intermediate= new IntermediateTLSProfileBuilder(intermediate); _visitables.get("intermediate").add(this.intermediate);} else { this.intermediate = null; _visitables.get("intermediate").remove(this.intermediate); } return (A) this;
  }
  public Boolean hasIntermediate() {
    return this.intermediate != null;
  }
  public TLSSecurityProfileFluent.IntermediateNested<A> withNewIntermediate() {
    return new TLSSecurityProfileFluentImpl.IntermediateNestedImpl();
  }
  public TLSSecurityProfileFluent.IntermediateNested<A> withNewIntermediateLike(IntermediateTLSProfile item) {
    return new TLSSecurityProfileFluentImpl.IntermediateNestedImpl(item);
  }
  public TLSSecurityProfileFluent.IntermediateNested<A> editIntermediate() {
    return withNewIntermediateLike(getIntermediate());
  }
  public TLSSecurityProfileFluent.IntermediateNested<A> editOrNewIntermediate() {
    return withNewIntermediateLike(getIntermediate() != null ? getIntermediate(): new IntermediateTLSProfileBuilder().build());
  }
  public TLSSecurityProfileFluent.IntermediateNested<A> editOrNewIntermediateLike(IntermediateTLSProfile item) {
    return withNewIntermediateLike(getIntermediate() != null ? getIntermediate(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildModern instead.
   * @return The buildable object.
   */
  @Deprecated
  public ModernTLSProfile getModern() {
    return this.modern!=null ?this.modern.build():null;
  }
  public ModernTLSProfile buildModern() {
    return this.modern!=null ?this.modern.build():null;
  }
  public A withModern(ModernTLSProfile modern) {
    _visitables.get("modern").remove(this.modern);
    if (modern!=null){ this.modern= new ModernTLSProfileBuilder(modern); _visitables.get("modern").add(this.modern);} else { this.modern = null; _visitables.get("modern").remove(this.modern); } return (A) this;
  }
  public Boolean hasModern() {
    return this.modern != null;
  }
  public TLSSecurityProfileFluent.ModernNested<A> withNewModern() {
    return new TLSSecurityProfileFluentImpl.ModernNestedImpl();
  }
  public TLSSecurityProfileFluent.ModernNested<A> withNewModernLike(ModernTLSProfile item) {
    return new TLSSecurityProfileFluentImpl.ModernNestedImpl(item);
  }
  public TLSSecurityProfileFluent.ModernNested<A> editModern() {
    return withNewModernLike(getModern());
  }
  public TLSSecurityProfileFluent.ModernNested<A> editOrNewModern() {
    return withNewModernLike(getModern() != null ? getModern(): new ModernTLSProfileBuilder().build());
  }
  public TLSSecurityProfileFluent.ModernNested<A> editOrNewModernLike(ModernTLSProfile item) {
    return withNewModernLike(getModern() != null ? getModern(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildOld instead.
   * @return The buildable object.
   */
  @Deprecated
  public OldTLSProfile getOld() {
    return this.old!=null ?this.old.build():null;
  }
  public OldTLSProfile buildOld() {
    return this.old!=null ?this.old.build():null;
  }
  public A withOld(OldTLSProfile old) {
    _visitables.get("old").remove(this.old);
    if (old!=null){ this.old= new OldTLSProfileBuilder(old); _visitables.get("old").add(this.old);} else { this.old = null; _visitables.get("old").remove(this.old); } return (A) this;
  }
  public Boolean hasOld() {
    return this.old != null;
  }
  public TLSSecurityProfileFluent.OldNested<A> withNewOld() {
    return new TLSSecurityProfileFluentImpl.OldNestedImpl();
  }
  public TLSSecurityProfileFluent.OldNested<A> withNewOldLike(OldTLSProfile item) {
    return new TLSSecurityProfileFluentImpl.OldNestedImpl(item);
  }
  public TLSSecurityProfileFluent.OldNested<A> editOld() {
    return withNewOldLike(getOld());
  }
  public TLSSecurityProfileFluent.OldNested<A> editOrNewOld() {
    return withNewOldLike(getOld() != null ? getOld(): new OldTLSProfileBuilder().build());
  }
  public TLSSecurityProfileFluent.OldNested<A> editOrNewOldLike(OldTLSProfile item) {
    return withNewOldLike(getOld() != null ? getOld(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TLSSecurityProfileFluentImpl that = (TLSSecurityProfileFluentImpl) o;
    if (custom != null ? !custom.equals(that.custom) :that.custom != null) return false;
    if (intermediate != null ? !intermediate.equals(that.intermediate) :that.intermediate != null) return false;
    if (modern != null ? !modern.equals(that.modern) :that.modern != null) return false;
    if (old != null ? !old.equals(that.old) :that.old != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(custom,  intermediate,  modern,  old,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (custom != null) { sb.append("custom:"); sb.append(custom + ","); }
    if (intermediate != null) { sb.append("intermediate:"); sb.append(intermediate + ","); }
    if (modern != null) { sb.append("modern:"); sb.append(modern + ","); }
    if (old != null) { sb.append("old:"); sb.append(old + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class CustomNestedImpl<N> extends CustomTLSProfileFluentImpl<TLSSecurityProfileFluent.CustomNested<N>> implements TLSSecurityProfileFluent.CustomNested<N>,Nested<N>{
    CustomNestedImpl(CustomTLSProfile item) {
      this.builder = new CustomTLSProfileBuilder(this, item);
    }
    CustomNestedImpl() {
      this.builder = new CustomTLSProfileBuilder(this);
    }
    CustomTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withCustom(builder.build());
    }
    public N endCustom() {
      return and();
    }
    
  }
  class IntermediateNestedImpl<N> extends IntermediateTLSProfileFluentImpl<TLSSecurityProfileFluent.IntermediateNested<N>> implements TLSSecurityProfileFluent.IntermediateNested<N>,Nested<N>{
    IntermediateNestedImpl(IntermediateTLSProfile item) {
      this.builder = new IntermediateTLSProfileBuilder(this, item);
    }
    IntermediateNestedImpl() {
      this.builder = new IntermediateTLSProfileBuilder(this);
    }
    IntermediateTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withIntermediate(builder.build());
    }
    public N endIntermediate() {
      return and();
    }
    
  }
  class ModernNestedImpl<N> extends ModernTLSProfileFluentImpl<TLSSecurityProfileFluent.ModernNested<N>> implements TLSSecurityProfileFluent.ModernNested<N>,Nested<N>{
    ModernNestedImpl(ModernTLSProfile item) {
      this.builder = new ModernTLSProfileBuilder(this, item);
    }
    ModernNestedImpl() {
      this.builder = new ModernTLSProfileBuilder(this);
    }
    ModernTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withModern(builder.build());
    }
    public N endModern() {
      return and();
    }
    
  }
  class OldNestedImpl<N> extends OldTLSProfileFluentImpl<TLSSecurityProfileFluent.OldNested<N>> implements TLSSecurityProfileFluent.OldNested<N>,Nested<N>{
    OldNestedImpl(OldTLSProfile item) {
      this.builder = new OldTLSProfileBuilder(this, item);
    }
    OldNestedImpl() {
      this.builder = new OldTLSProfileBuilder(this);
    }
    OldTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withOld(builder.build());
    }
    public N endOld() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/TLSSecurityProfileFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TLSSecurityProfileFluentImpl<A extends TLSSecurityProfileFluent<A>> extends BaseFluent<A> implements TLSSecurityProfileFluent<A>{
  public TLSSecurityProfileFluentImpl() {
  }
  public TLSSecurityProfileFluentImpl(TLSSecurityProfile instance) {
    if (instance != null) {
      this.withCustom(instance.getCustom());
      this.withIntermediate(instance.getIntermediate());
      this.withModern(instance.getModern());
      this.withOld(instance.getOld());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private CustomTLSProfileBuilder custom;
  private IntermediateTLSProfileBuilder intermediate;
  private ModernTLSProfileBuilder modern;
  private OldTLSProfileBuilder old;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCustom instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomTLSProfile getCustom() {
    return this.custom!=null ?this.custom.build():null;
  }
  public CustomTLSProfile buildCustom() {
    return this.custom!=null ?this.custom.build():null;
  }
  public A withCustom(CustomTLSProfile custom) {
    _visitables.get("custom").remove(this.custom);
    if (custom!=null){ this.custom= new CustomTLSProfileBuilder(custom); _visitables.get("custom").add(this.custom);} else { this.custom = null; _visitables.get("custom").remove(this.custom); } return (A) this;
  }
  public Boolean hasCustom() {
    return this.custom != null;
  }
  public TLSSecurityProfileFluentImpl.CustomNested<A> withNewCustom() {
    return new TLSSecurityProfileFluentImpl.CustomNestedImpl();
  }
  public TLSSecurityProfileFluentImpl.CustomNested<A> withNewCustomLike(CustomTLSProfile item) {
    return new TLSSecurityProfileFluentImpl.CustomNestedImpl(item);
  }
  public TLSSecurityProfileFluentImpl.CustomNested<A> editCustom() {
    return withNewCustomLike(getCustom());
  }
  public TLSSecurityProfileFluentImpl.CustomNested<A> editOrNewCustom() {
    return withNewCustomLike(getCustom() != null ? getCustom(): new CustomTLSProfileBuilder().build());
  }
  public TLSSecurityProfileFluentImpl.CustomNested<A> editOrNewCustomLike(CustomTLSProfile item) {
    return withNewCustomLike(getCustom() != null ? getCustom(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildIntermediate instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntermediateTLSProfile getIntermediate() {
    return this.intermediate!=null ?this.intermediate.build():null;
  }
  public IntermediateTLSProfile buildIntermediate() {
    return this.intermediate!=null ?this.intermediate.build():null;
  }
  public A withIntermediate(IntermediateTLSProfile intermediate) {
    _visitables.get("intermediate").remove(this.intermediate);
    if (intermediate!=null){ this.intermediate= new IntermediateTLSProfileBuilder(intermediate); _visitables.get("intermediate").add(this.intermediate);} else { this.intermediate = null; _visitables.get("intermediate").remove(this.intermediate); } return (A) this;
  }
  public Boolean hasIntermediate() {
    return this.intermediate != null;
  }
  public TLSSecurityProfileFluentImpl.IntermediateNested<A> withNewIntermediate() {
    return new TLSSecurityProfileFluentImpl.IntermediateNestedImpl();
  }
  public TLSSecurityProfileFluentImpl.IntermediateNested<A> withNewIntermediateLike(IntermediateTLSProfile item) {
    return new TLSSecurityProfileFluentImpl.IntermediateNestedImpl(item);
  }
  public TLSSecurityProfileFluentImpl.IntermediateNested<A> editIntermediate() {
    return withNewIntermediateLike(getIntermediate());
  }
  public TLSSecurityProfileFluentImpl.IntermediateNested<A> editOrNewIntermediate() {
    return withNewIntermediateLike(getIntermediate() != null ? getIntermediate(): new IntermediateTLSProfileBuilder().build());
  }
  public TLSSecurityProfileFluentImpl.IntermediateNested<A> editOrNewIntermediateLike(IntermediateTLSProfile item) {
    return withNewIntermediateLike(getIntermediate() != null ? getIntermediate(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildModern instead.
   * @return The buildable object.
   */
  @Deprecated
  public ModernTLSProfile getModern() {
    return this.modern!=null ?this.modern.build():null;
  }
  public ModernTLSProfile buildModern() {
    return this.modern!=null ?this.modern.build():null;
  }
  public A withModern(ModernTLSProfile modern) {
    _visitables.get("modern").remove(this.modern);
    if (modern!=null){ this.modern= new ModernTLSProfileBuilder(modern); _visitables.get("modern").add(this.modern);} else { this.modern = null; _visitables.get("modern").remove(this.modern); } return (A) this;
  }
  public Boolean hasModern() {
    return this.modern != null;
  }
  public TLSSecurityProfileFluentImpl.ModernNested<A> withNewModern() {
    return new TLSSecurityProfileFluentImpl.ModernNestedImpl();
  }
  public TLSSecurityProfileFluentImpl.ModernNested<A> withNewModernLike(ModernTLSProfile item) {
    return new TLSSecurityProfileFluentImpl.ModernNestedImpl(item);
  }
  public TLSSecurityProfileFluentImpl.ModernNested<A> editModern() {
    return withNewModernLike(getModern());
  }
  public TLSSecurityProfileFluentImpl.ModernNested<A> editOrNewModern() {
    return withNewModernLike(getModern() != null ? getModern(): new ModernTLSProfileBuilder().build());
  }
  public TLSSecurityProfileFluentImpl.ModernNested<A> editOrNewModernLike(ModernTLSProfile item) {
    return withNewModernLike(getModern() != null ? getModern(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildOld instead.
   * @return The buildable object.
   */
  @Deprecated
  public OldTLSProfile getOld() {
    return this.old!=null ?this.old.build():null;
  }
  public OldTLSProfile buildOld() {
    return this.old!=null ?this.old.build():null;
  }
  public A withOld(OldTLSProfile old) {
    _visitables.get("old").remove(this.old);
    if (old!=null){ this.old= new OldTLSProfileBuilder(old); _visitables.get("old").add(this.old);} else { this.old = null; _visitables.get("old").remove(this.old); } return (A) this;
  }
  public Boolean hasOld() {
    return this.old != null;
  }
  public TLSSecurityProfileFluentImpl.OldNested<A> withNewOld() {
    return new TLSSecurityProfileFluentImpl.OldNestedImpl();
  }
  public TLSSecurityProfileFluentImpl.OldNested<A> withNewOldLike(OldTLSProfile item) {
    return new TLSSecurityProfileFluentImpl.OldNestedImpl(item);
  }
  public TLSSecurityProfileFluentImpl.OldNested<A> editOld() {
    return withNewOldLike(getOld());
  }
  public TLSSecurityProfileFluentImpl.OldNested<A> editOrNewOld() {
    return withNewOldLike(getOld() != null ? getOld(): new OldTLSProfileBuilder().build());
  }
  public TLSSecurityProfileFluentImpl.OldNested<A> editOrNewOldLike(OldTLSProfile item) {
    return withNewOldLike(getOld() != null ? getOld(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TLSSecurityProfileFluentImpl that = (TLSSecurityProfileFluentImpl) o;
    if (!java.util.Objects.equals(custom, that.custom)) return false;

    if (!java.util.Objects.equals(intermediate, that.intermediate)) return false;

    if (!java.util.Objects.equals(modern, that.modern)) return false;

    if (!java.util.Objects.equals(old, that.old)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(custom,  intermediate,  modern,  old,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (custom != null) { sb.append("custom:"); sb.append(custom + ","); }
    if (intermediate != null) { sb.append("intermediate:"); sb.append(intermediate + ","); }
    if (modern != null) { sb.append("modern:"); sb.append(modern + ","); }
    if (old != null) { sb.append("old:"); sb.append(old + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class CustomNestedImpl<N> extends CustomTLSProfileFluentImpl<TLSSecurityProfileFluentImpl.CustomNested<N>> implements TLSSecurityProfileFluentImpl.CustomNested<N>,Nested<N>{
    CustomNestedImpl(CustomTLSProfile item) {
      this.builder = new CustomTLSProfileBuilder(this, item);
    }
    CustomNestedImpl() {
      this.builder = new CustomTLSProfileBuilder(this);
    }
    CustomTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withCustom(builder.build());
    }
    public N endCustom() {
      return and();
    }
    
  }
  class IntermediateNestedImpl<N> extends IntermediateTLSProfileFluentImpl<TLSSecurityProfileFluentImpl.IntermediateNested<N>> implements TLSSecurityProfileFluentImpl.IntermediateNested<N>,Nested<N>{
    IntermediateNestedImpl(IntermediateTLSProfile item) {
      this.builder = new IntermediateTLSProfileBuilder(this, item);
    }
    IntermediateNestedImpl() {
      this.builder = new IntermediateTLSProfileBuilder(this);
    }
    IntermediateTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withIntermediate(builder.build());
    }
    public N endIntermediate() {
      return and();
    }
    
  }
  class ModernNestedImpl<N> extends ModernTLSProfileFluentImpl<TLSSecurityProfileFluentImpl.ModernNested<N>> implements TLSSecurityProfileFluentImpl.ModernNested<N>,Nested<N>{
    ModernNestedImpl(ModernTLSProfile item) {
      this.builder = new ModernTLSProfileBuilder(this, item);
    }
    ModernNestedImpl() {
      this.builder = new ModernTLSProfileBuilder(this);
    }
    ModernTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withModern(builder.build());
    }
    public N endModern() {
      return and();
    }
    
  }
  class OldNestedImpl<N> extends OldTLSProfileFluentImpl<TLSSecurityProfileFluentImpl.OldNested<N>> implements TLSSecurityProfileFluentImpl.OldNested<N>,Nested<N>{
    OldNestedImpl(OldTLSProfile item) {
      this.builder = new OldTLSProfileBuilder(this, item);
    }
    OldNestedImpl() {
      this.builder = new OldTLSProfileBuilder(this);
    }
    OldTLSProfileBuilder builder;
    public N and() {
      return (N) TLSSecurityProfileFluentImpl.this.withOld(builder.build());
    }
    public N endOld() {
      return and();
    }
    
  }
  
}
